@@ -11,17 +11,38 @@ import pandas as pd
 from collections import defaultdict
 from transformers import AutoTokenizer
 
-from .utils import (get_model, get_idf_dict, bert_cos_score_idf,
-                    get_bert_embedding, model_types,
-                    lang2model, model2layers, get_hash,
-                    cache_scibert, sent_encode)
+from .utils import (
+    get_model,
+    get_idf_dict,
+    bert_cos_score_idf,
+    get_bert_embedding,
+    model_types,
+    lang2model,
+    model2layers,
+    get_hash,
+    cache_scibert,
+    sent_encode,
+)
 
 
-__all__ = ['score', 'plot_example']
+__all__ = ["score", "plot_example"]
 
-def score(cands, refs, model_type=None, num_layers=None, verbose=False, 
-          idf=False, device=None, batch_size=64, nthreads=4, all_layers=False, 
-          lang=None, return_hash=False, rescale_with_baseline=False):
+
+def score(
+    cands,
+    refs,
+    model_type=None,
+    num_layers=None,
+    verbose=False,
+    idf=False,
+    device=None,
+    batch_size=64,
+    nthreads=4,
+    all_layers=False,
+    lang=None,
+    return_hash=False,
+    rescale_with_baseline=False,
+):
     """
     BERTScore metric.
 
@@ -54,8 +75,7 @@ def score(cands, refs, model_type=None, num_layers=None, verbose=False,
     """
     assert len(cands) == len(refs), "Different number of candidates and references"
 
-    assert lang is not None or model_type is not None, \
-        'Either lang or model_type should be specified'
+    assert lang is not None or model_type is not None, "Either lang or model_type should be specified"
 
     ref_group_boundaries = None
     if not isinstance(refs[0], str):
@@ -70,7 +90,7 @@ def score(cands, refs, model_type=None, num_layers=None, verbose=False,
             count += len(ref_group)
 
     if rescale_with_baseline:
-        assert lang is not None, 'Need to specify Language when rescaling with baseline'
+        assert lang is not None, "Need to specify Language when rescaling with baseline"
 
     if model_type is None:
         lang = lang.lower()
@@ -78,38 +98,46 @@ def score(cands, refs, model_type=None, num_layers=None, verbose=False,
     if num_layers is None:
         num_layers = model2layers[model_type]
 
-    if model_type.startswith('scibert'):
+    if model_type.startswith("scibert"):
         tokenizer = AutoTokenizer.from_pretrained(cache_scibert(model_type))
     else:
         tokenizer = AutoTokenizer.from_pretrained(model_type)
 
     model = get_model(model_type, num_layers, all_layers)
-    device = 'cuda' if torch.cuda.is_available() else 'cpu'
+    device = "cuda" if torch.cuda.is_available() else "cpu"
     model.to(device)
 
     if not idf:
-        idf_dict = defaultdict(lambda: 1.)
+        idf_dict = defaultdict(lambda: 1.0)
         # set idf for [SEP] and [CLS] to 0
         idf_dict[tokenizer.sep_token_id] = 0
         idf_dict[tokenizer.cls_token_id] = 0
     elif isinstance(idf, dict):
         if verbose:
-            print('using predefined IDF dict...')
+            print("using predefined IDF dict...")
         idf_dict = idf
     else:
         if verbose:
-            print('preparing IDF dict...')
+            print("preparing IDF dict...")
         start = time.perf_counter()
         idf_dict = get_idf_dict(refs, tokenizer, nthreads=nthreads)
         if verbose:
-            print('done in {:.2f} seconds'.format(time.perf_counter() - start))
+            print("done in {:.2f} seconds".format(time.perf_counter() - start))
 
     if verbose:
-        print('calculating scores...')
+        print("calculating scores...")
     start = time.perf_counter()
-    all_preds = bert_cos_score_idf(model, refs, cands, tokenizer, idf_dict,
-                                   verbose=verbose, device=device,
-                                   batch_size=batch_size, all_layers=all_layers).cpu()
+    all_preds = bert_cos_score_idf(
+        model,
+        refs,
+        cands,
+        tokenizer,
+        idf_dict,
+        verbose=verbose,
+        device=device,
+        batch_size=batch_size,
+        all_layers=all_layers,
+    ).cpu()
 
     if ref_group_boundaries is not None:
         max_preds = []
@@ -118,37 +146,32 @@ def score(cands, refs, model_type=None, num_layers=None, verbose=False,
         all_preds = torch.stack(max_preds, dim=0)
 
     if rescale_with_baseline:
-        baseline_path = os.path.join(
-            os.path.dirname(__file__),
-            f'rescale_baseline/{lang}/{model_type}.tsv'
-        )
+        baseline_path = os.path.join(os.path.dirname(__file__), f"rescale_baseline/{lang}/{model_type}.tsv")
         if os.path.isfile(baseline_path):
             if not all_layers:
-                baselines = torch.from_numpy(
-                    pd.read_csv(baseline_path).iloc[num_layers].to_numpy()
-                )[1:].float()
+                baselines = torch.from_numpy(pd.read_csv(baseline_path).iloc[num_layers].to_numpy())[1:].float()
             else:
-                baselines = torch.from_numpy(
-                    pd.read_csv(baseline_path).to_numpy()
-                )[:, 1:].unsqueeze(1).float()
+                baselines = torch.from_numpy(pd.read_csv(baseline_path).to_numpy())[:, 1:].unsqueeze(1).float()
 
             all_preds = (all_preds - baselines) / (1 - baselines)
         else:
-            print(f'Warning: Baseline not Found for {model_type} on {lang} at {baseline_path}', file=sys.stderr)
+            print(f"Warning: Baseline not Found for {model_type} on {lang} at {baseline_path}", file=sys.stderr)
 
-    out = all_preds[..., 0], all_preds[..., 1], all_preds[..., 2] # P, R, F
+    out = all_preds[..., 0], all_preds[..., 1], all_preds[..., 2]  # P, R, F
 
     if verbose:
         time_diff = time.perf_counter() - start
-        print(f'done in {time_diff:.2f} seconds, {len(refs) / time_diff:.2f} sentences/sec')
+        print(f"done in {time_diff:.2f} seconds, {len(refs) / time_diff:.2f} sentences/sec")
 
     if return_hash:
         return tuple([out, get_hash(model_type, num_layers, idf, rescale_with_baseline)])
 
     return out
 
-def plot_example(candidate, reference, model_type=None, num_layers=None, lang=None, 
-                 rescale_with_baseline=False, fname=''):
+
+def plot_example(
+    candidate, reference, model_type=None, num_layers=None, lang=None, rescale_with_baseline=False, fname=""
+):
     """
     BERTScore metric.
 
@@ -170,11 +193,10 @@ def plot_example(candidate, reference, model_type=None, num_layers=None, lang=No
     assert isinstance(candidate, str)
     assert isinstance(reference, str)
 
-    assert lang is not None or model_type is not None, \
-        'Either lang or model_type should be specified'
+    assert lang is not None or model_type is not None, "Either lang or model_type should be specified"
 
     if rescale_with_baseline:
-        assert lang is not None, 'Need to specify Language when rescaling with baseline'
+        assert lang is not None, "Need to specify Language when rescaling with baseline"
 
     if model_type is None:
         lang = lang.lower()
@@ -182,23 +204,25 @@ def plot_example(candidate, reference, model_type=None, num_layers=None, lang=No
     if num_layers is None:
         num_layers = model2layers[model_type]
 
-    if model_type.startswith('scibert'):
+    if model_type.startswith("scibert"):
         tokenizer = AutoTokenizer.from_pretrained(cache_scibert(model_type))
     else:
         tokenizer = AutoTokenizer.from_pretrained(model_type)
     model = get_model(model_type, num_layers)
-    device = 'cuda' if torch.cuda.is_available() else 'cpu'
+    device = "cuda" if torch.cuda.is_available() else "cpu"
     model.to(device)
 
-    idf_dict = defaultdict(lambda: 1.)
+    idf_dict = defaultdict(lambda: 1.0)
     # set idf for [SEP] and [CLS] to 0
     idf_dict[tokenizer.sep_token_id] = 0
     idf_dict[tokenizer.cls_token_id] = 0
 
-    hyp_embedding, masks, padded_idf = get_bert_embedding([candidate], model, tokenizer, idf_dict,
-                                                         device=device, all_layers=False)
-    ref_embedding, masks, padded_idf = get_bert_embedding([reference], model, tokenizer, idf_dict,
-                                                         device=device, all_layers=False)
+    hyp_embedding, masks, padded_idf = get_bert_embedding(
+        [candidate], model, tokenizer, idf_dict, device=device, all_layers=False
+    )
+    ref_embedding, masks, padded_idf = get_bert_embedding(
+        [reference], model, tokenizer, idf_dict, device=device, all_layers=False
+    )
     ref_embedding.div_(torch.norm(ref_embedding, dim=-1).unsqueeze(-1))
     hyp_embedding.div_(torch.norm(hyp_embedding, dim=-1).unsqueeze(-1))
     sim = torch.bmm(hyp_embedding, ref_embedding.transpose(1, 2))
@@ -207,23 +231,18 @@ def plot_example(candidate, reference, model_type=None, num_layers=None, lang=No
     # remove [CLS] and [SEP] tokens
     r_tokens = [tokenizer.decode([i]) for i in sent_encode(tokenizer, reference)][1:-1]
     h_tokens = [tokenizer.decode([i]) for i in sent_encode(tokenizer, candidate)][1:-1]
-    sim = sim[1:-1,1:-1]
+    sim = sim[1:-1, 1:-1]
 
     if rescale_with_baseline:
-        baseline_path = os.path.join(
-            os.path.dirname(__file__),
-            f"rescale_baseline/{lang}/{model_type}.tsv"
-        )
+        baseline_path = os.path.join(os.path.dirname(__file__), f"rescale_baseline/{lang}/{model_type}.tsv")
         if os.path.isfile(baseline_path):
-            baselines = torch.from_numpy(
-                pd.read_csv(baseline_path).iloc[num_layers].to_numpy()
-            )[1:].float()
+            baselines = torch.from_numpy(pd.read_csv(baseline_path).iloc[num_layers].to_numpy())[1:].float()
             sim = (sim - baselines[2].item()) / (1 - baselines[2].item())
         else:
-            print(f'Warning: Baseline not Found for {model_type} on {lang} at {baseline_path}', file=sys.stderr)
+            print(f"Warning: Baseline not Found for {model_type} on {lang} at {baseline_path}", file=sys.stderr)
 
     fig, ax = plt.subplots(figsize=(len(r_tokens), len(h_tokens)))
-    im = ax.imshow(sim, cmap='Blues', vmin=0, vmax=1)
+    im = ax.imshow(sim, cmap="Blues", vmin=0, vmax=1)
 
     # We want to show all ticks...
     ax.set_xticks(np.arange(len(r_tokens)))
@@ -244,14 +263,19 @@ def plot_example(candidate, reference, model_type=None, num_layers=None, lang=No
     fig.colorbar(im, cax=cax)
 
     # Rotate the tick labels and set their alignment.
-    plt.setp(ax.get_xticklabels(), rotation=45, ha="right",
-             rotation_mode="anchor")
+    plt.setp(ax.get_xticklabels(), rotation=45, ha="right", rotation_mode="anchor")
 
     # Loop over data dimensions and create text annotations.
     for i in range(len(h_tokens)):
         for j in range(len(r_tokens)):
-            text = ax.text(j, i, '{:.3f}'.format(sim[i, j].item()),
-                           ha="center", va="center", color="k" if sim[i, j].item() < 0.5 else "w")
+            text = ax.text(
+                j,
+                i,
+                "{:.3f}".format(sim[i, j].item()),
+                ha="center",
+                va="center",
+                color="k" if sim[i, j].item() < 0.5 else "w",
+            )
 
     fig.tight_layout()
     if fname != "":
